// Reloader utility
// Copyright (c) 2001 Alexander Ananiev & MyArch.com.  All rights reserved.

package com.myarch.reloader;


/**
 * <code>LoadActionListener</code> can be used to develop loggers. Used by <code>ReloadLogger</code>.
 * <br><code>Reloader</code> calls action listener several times during loading
 * of a class and passes event (action) which action listener can process.
 * See <code>Actions</code> class for the list of actions.
 *
 * @author Alexander Ananiev
 */
public interface LoadActionListener {

 /**
  *<code>Reloader</code> calls this method every time it tries to load a class.
  *
  * @param action type of a loading event, such as "before loading by reloader", "successful loading by reloader",
  * "successful loading by parent loader" and so on. See <code>Actions</code> class for details.
  * @param name name of a class being loaded.
  * @param mainClassName name of the "main" class, i.e., the class passed as a parameter to <code>reload</code> method.
  * @param loader the actual class loader used to load a class. Can be a class loader created by <code>Reloader</code>
  * or a parent class loader, such as system class loader.
  */
  public void actionPerformed( int action, String name, String mainClassName,
    ClassLoader loader );

}