// Reloader utility
// Copyright (c) 2001 Alexander Ananiev & MyArch.com.  All rights reserved.

package com.myarch.reloader;

/**
 * Makes <code>Reloader</code> to re-load all classes passed to it.
 * <code>ReloadAllController</code> should only be used if <code>Reloader</code>
 * was provided with custom URLs for reloadable classes .
 * Otherwise, if this loader loads from system class path,
 * the <code>ClassCastException</code> is inevitable.
 *
 * @author Alexander Ananiev
 */
public class ReloadAllController  implements LoadController {

  /**
   * Always returns <code>true</code> thus forcing <code>Reloader</code>
   * to load all classes.
   * @param className class name to load
   * @param mainClassName name of the "main" class.
   * Main class is a class passed as a parameter to <code>Reloader.reload()</code> method.
   * @param loader the actual class loader used to load a class
   * @return <code>true</code> at all times
   */
  public boolean isReloadAllowed( String className, String mainClassName,
    ClassLoader loader) {
    return true;
  }

  /**
   * Allows using parent loader. This ensures that a class that was not found
   * on the custom class path will be loaded by the parent loaded from the system class path.
   *
   * @param className class name to load
   * @param mainClassName name of the "main" class.
   * Main class is a class passed as a parameter to <code>Reloader.reload()</code> method.
   * @param loader the actual class loader used to load a class (parent loader).
   * @return <code>true</code> all the time to make <code>Reloader</code> to use the parent loader.
   */
  public boolean isLoadByParentAllowed( String className, String mainClassName,
    ClassLoader loader) {

    return true;
  }

}