// Reloader utility
// Copyright (c) 2001 Alexander Ananiev & MyArch.com.  All rights reserved.

package com.myarch.reloader;

/**
 * Makes <code>Reloader</code> to re-load only the main class.
 * Main class is the one that was explicitly passed to <code>reload()</code> as a parameter.
 * All other classes won't be re-loaded.
 * This controller is default for <code>Reloader</code>
 *<p>
 * It is the most simple way to manipulate dynamic reloading. Simply use <code>Reloader</code>
 * for ALL classes that are supposed to be reloadable, do not call classes directly.
 * You will have to create an interface for each class.
 *
 * @author Alexander Ananiev
 */
public class ReloadMainController  implements LoadController {


  /**
   * Returns  <code>true</code> if a class to reload is the main class.
   *
   * @param className class name to load
   * @param mainClassName name of the "main" class.
   * Main class is a class passed as a parameter to <code>Reloader.reload()</code> method.
   * @param loader the actual class loader used to load a class
   * @return <code>true</code> if <code>mainClassName.equals(className)</code>
   */
  public boolean isReloadAllowed( String className, String mainClassName,
    ClassLoader loader) {
    return ( className.equals( mainClassName ) );
  }

  /**
   * Prohibits using parent loader for loadable classes.
   * This ensures that the class (main class in this case) is either loaded
   * by the <code>Reloader</code> or  <code>ClassNotFoundException</code> is thrown.
   *
   * @param className class name to load
   * @param mainClassName name of the "main" class.
   * Main class is a class passed as a parameter to <code>Reloader.reload()</code> method.
   * @param loader the actual class loader used to load a class (parent loader).
   * @return <code>false</code> all the time to prohibit using the parent loader.
   */
  public boolean isLoadByParentAllowed( String className, String mainClassName,
    ClassLoader loader) {
    return false;
    //return (!isReloadAllowed( className, mainClassName, loader ));
  }

}